# ver 0.1.7
- rollover 시 생성되는 log 파일을 특정 기간 기준 삭제하는 함수 log_del 추가
## ver 0.1.7.1 
- log_del 에 print 추가
# ver 0.1.6
- log 생성시 log_id 를 반드시 지정하도록 변경
- log handler 를 중복 생성하지 않도록 설정하여 log 기록 중첩을 방지
# ver 0.1.5 
- log 찍을 시 console display 추가
log 생성용 모듈